Method: Gnuplot::Plot#set

Defined in:
lib/gnuplot.rb

#set(var, value = '') ⇒ Object Also known as: []=

Set a variable to the given value. var must be a GNUPLOT variable and value must be the value to set it to. Automatic quoting will be performed if the variable requires it (see QUOTED).



133
134
135
136
137
138
# File 'lib/gnuplot.rb', line 133

def set(var, value = '')
  var   = var.to_s
  value = %Q{"#{value}"} if QUOTED.include?(var) && value !~ /\A'.*'\z/

  @sets << [var, value]
end